@@ -46,7 +46,7 @@
 
 #define QT_FEATURE_posix_shm 1
 
-#define QT_FEATURE_pthread_clockjoin -1
+#define QT_FEATURE_pthread_clockjoin 1
 
 #define QT_FEATURE_pthread_condattr_setclock 1
 
