@@ -1,4 +1,4 @@
-#define QT_FEATURE_accessibility_atspi_bridge -1
+#define QT_FEATURE_accessibility_atspi_bridge 1
 
 #define QT_FEATURE_directfb -1
 
@@ -6,11 +6,17 @@
 
 #define QT_FEATURE_directwrite3 -1
 
+#define QT_FEATURE_directwritecolrv1 -1
+
 #define QT_FEATURE_direct2d -1
 
 #define QT_FEATURE_direct2d1_1 -1
 
-#define QT_FEATURE_evdev -1
+#define QT_FEATURE_emojisegmenter 1
+
+#define QT_FEATURE_evdev 1
+
+#define QT_FEATURE_vxworksevdev -1
 
 #define QT_FEATURE_freetype 1
 
@@ -44,7 +50,7 @@
 
 #define QT_FEATURE_vnc 1
 
-#define QT_FEATURE_mtdev -1
+#define QT_FEATURE_mtdev 1
 
 #define QT_FEATURE_vkgen 1
 
@@ -118,5 +124,9 @@
 
 #define QT_FEATURE_raster_fp 1
 
+#define QT_FEATURE_qtgui_threadpool 1
+
 #define QT_FEATURE_graphicsframecapture -1
 
+#define QT_FEATURE_run_opengl_tests 1
+
