@@ -1,4 +1,4 @@
-#define QT_FEATURE_accessibility_atspi_bridge -1
+#define QT_FEATURE_accessibility_atspi_bridge 1
 
 #define QT_FEATURE_emojisegmenter 1
 
@@ -112,4 +112,3 @@
 
 #define QT_FEATURE_wayland 1
 
-#define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
